<template>
  <ContentScrollView :paddingH="false">
    <nut-form :model-value="form" ref="formRef">
      <nut-form-item label="工作年限:" class="bole-form-item" prop="workingSeniority">
        <nut-input v-model="form.workingSeniority" placeholder="请输入"> </nut-input>
      </nut-form-item>
      <nut-form-item label="工作经验:" class="bole-form-item" prop="workExperience">
        <nut-input v-model="form.workExperience" type="textarea" placeholder="请输入"> </nut-input>
      </nut-form-item>
    </nut-form>
  </ContentScrollView>
  <PageFooter>
    <PageFooterBtn type="primary" @click="handleConfirm">保存</PageFooterBtn>
  </PageFooter>
</template>

<script setup lang="ts">
import { goBack } from '@/utils';
import * as userResumeServices from '@12333/services/api/userResume';
import { Message } from '@12333/utils';
import { useQuery } from '@tanstack/vue-query';

defineOptions({
  name: 'InnerPage',
});

const form = reactive({
  workingSeniority: '',
  workExperience: '',
});

const {
  isLoading,
  isError,
  data: detail,
  refetch,
} = useQuery({
  queryKey: ['userResumeServices/getUserResumeWorkExperience'],
  queryFn: async () => {
    return await userResumeServices.getUserResumeWorkExperience({
      showLoading: false,
    });
  },
  placeholderData: () => ({} as API.UserResumeWorkExperienceOutput),
  onSuccess(data) {
    form.workingSeniority = data.workingSeniority;
    form.workExperience = data.workExperience;
  },
});

async function handleConfirm() {
  try {
    let params: API.SaveUserResumeWorkExperienceInput = {
      workingSeniority: form.workingSeniority,
      workExperience: form.workExperience,
    };
    let res = await userResumeServices.saveUserResumeWorkExperience(params);
    if (res) {
      Message.success('保存成功', {
        onClosed() {
          goBack();
        },
      });
    }
  } catch (error) {}
}
</script>

<style lang="scss">
@import '@/styles/common.scss';
</style>
